pub fn unstable_unstable_export()Available on crate feature
unstable-reexport only.Expand description
An unstable reexport of a private unstable item
This export is unstable. The availability section on this will be appended to the availability section of the unstable_private_function, which will look odd. Consider avoiding re-exporting unstable items like this, and instead only mark the re-export itself as unstable. An unstable private function
This function is unstable.
Stability
This API is marked as unstable and is only available when the unstable-private-function
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.