pub trait UnstableTrait {
// Provided method
fn stable_trait_method(&self) { ... }
}Available on crate feature
unstable-trait only.Expand description
An unstable trait
This trait is unstable
Stability
This API is marked as unstable and is only available when the unstable-trait
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Provided Methods
Sourcefn stable_trait_method(&self)
fn stable_trait_method(&self)
A stable trait method
This method is stable.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl UnstableTrait for StableStruct
Stability
This API is marked as unstable and is only available when the unstable-trait
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.